@@ -56,7 +56,7 @@ void
 idview_get_overrides(struct backend_search_cbdata *cbdata)
 {
 	char *dn = NULL;
-	int ret = 0, result = 0;
+	int result = 0;
 	const Slapi_DN *suffix = NULL;
 	Slapi_PBlock *pb;
 
@@ -76,7 +76,7 @@ idview_get_overrides(struct backend_search_cbdata *cbdata)
 	slapi_search_internal_set_pb(pb, dn, LDAP_SCOPE_SUBTREE,
 				     "(objectclass=ipaOverrideAnchor)", NULL, 0,
 				     NULL, NULL, cbdata->state->plugin_identity, 0);
-	ret = slapi_search_internal_pb(pb);
+	slapi_search_internal_pb(pb);
 	slapi_ch_free_string(&dn);
 	slapi_pblock_get(pb, SLAPI_PLUGIN_INTOP_RESULT, &result);
 
@@ -121,7 +121,7 @@ idview_process_overrides(struct backend_search_cbdata *cbdata,
 					 "createtimestamp", "modifytimestamp", "parentid",
 					 "entryusn", "entryid", "entrydn", "ipaoriginaluid",
 					 "ipaanchoruuid", "nsuniqueid", "ipasshpubkey", NULL };
-	char *new_dn = NULL, *new_key = NULL, *sep = NULL, *new_val = NULL;
+	char *new_dn = NULL, *sep = NULL, *new_val = NULL;
 	char *override_type = NULL;
 	Slapi_Entry *override_entry = NULL;
 	Slapi_Attr *anchor = NULL, *id_attr = NULL;
@@ -180,6 +180,7 @@ idview_process_overrides(struct backend_search_cbdata *cbdata,
 				}
 				result = slapi_attr_get_valueset(override_attr, &override_valueset);
 				result = slapi_entry_add_valueset(entry, override_type, override_valueset);
+				slapi_valueset_free(override_valueset);
 			}
 			result = slapi_entry_next_attr(override_entry, override_attr, &override_attr);
 		}
@@ -287,6 +288,7 @@ idview_replace_target_dn(char **target, char **idview)
 			new_target = slapi_ch_smprintf("%s", cnviews+10);
 		}
 		cnviews[0] = ',';
+		slapi_ch_free_string(target);
 		*target = new_target;
 	}
 }
@@ -411,8 +413,6 @@ idview_replace_filter(struct backend_search_cbdata *cbdata)
 {
 	struct backend_search_filter_config config =
 		{FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, NULL, NULL, NULL};
-	int res = 0;
-
 	if (cbdata->idview == NULL) {
 		return;
 	}
@@ -421,7 +421,7 @@ idview_replace_filter(struct backend_search_cbdata *cbdata)
 	config.callback_data = cbdata;
 
 	/* Ignore the return code as it will always be SLAPI_FILTER_SCAN_NO_MORE */
-	res = backend_analyze_search_filter(cbdata->filter, &config);
+	(void)backend_analyze_search_filter(cbdata->filter, &config);
 
 	if (config.name != NULL) {
 		slapi_ch_free_string(&config.name);
