@@ -1767,6 +1767,7 @@ backend_search_cb(Slapi_PBlock *pb)
 			/* Perform another check, now for rewritten DN */
 			cbdata.target_dn = slapi_sdn_new_dn_byval(target);
 			map_data_foreach_domain(cbdata.state, backend_search_find_set_dn_cb, &cbdata);
+
 			/* Rewritten DN might still be outside of our trees */
 			if (cbdata.answer == TRUE) {
 				slapi_log_error(SLAPI_LOG_PLUGIN, cbdata.state->plugin_desc->spd_id,
@@ -1774,18 +1775,24 @@ backend_search_cb(Slapi_PBlock *pb)
 						"for \"%s\" with scope %d%s. Filter may get overridden later.\n",
 						cbdata.idview, target, cbdata.strfilter, cbdata.scope,
 						backend_sch_scope_as_string(cbdata.scope));
-			} else {
-				slapi_sdn_free(&cbdata.target_dn);
-				slapi_ch_free_string(&target);
-				slapi_ch_free_string(&cbdata.idview);
+			}
+
+			slapi_sdn_free(&cbdata.target_dn);
+			slapi_ch_free_string(&cbdata.idview);
+
+			if (cbdata.answer == FALSE) {
 				slapi_log_error(SLAPI_LOG_PLUGIN,
 						cbdata.state->plugin_desc->spd_id,
 						"The search base didn't match any of the containers, "
 						"ignoring search\n");
+				slapi_ch_free_string(&target);
 				return 0;
 			}
-		} else {
-			slapi_ch_free_string(&target);
+		}
+		slapi_ch_free_string(&target);
+		if (cbdata.answer == FALSE) {
+			/* None of the configured trees in the sets matched the target at all, ignore search */
+			return 0;
 		}
 	}
 	cbdata.answer = FALSE;
@@ -1981,6 +1988,11 @@ backend_locate_cb(const char *group, const char *set, bool_t flag,
 		rdn = slapi_rdn_new_sdn(cbdata->target_dn);
 		if (rdn != NULL) {
 			rdnstr = slapi_rdn_get_nrdn(rdn);
+			if (rdnstr == NULL) {
+				/* normalizing RDN failed, break the search */
+				slapi_rdn_free(&rdn);
+				return FALSE;
+			}
 			if (map_match(cbdata->state, group, set, &flag,
 				      strlen(rdnstr), rdnstr,
 				      &ndnlen, &ndn,
@@ -2342,36 +2354,16 @@ backend_betxn_pre_write_cb(Slapi_PBlock *pb)
 {
 	struct plugin_state *state;
 
+    if (backend_shr_write_ignore(pb)) {
+#if DEBUG_MAP_LOCK
+        slapi_log_error(SLAPI_LOG_FATAL, "schemacompat",
+                "backend_betxn_pre_write_cb: (%p) operation is not impacting schema compat\n", PR_MyThreadId(), 1);
+#endif
+        return 0;
+    }
 	slapi_pblock_get(pb, SLAPI_PLUGIN_PRIVATE, &state);
 	return state->use_be_txns ? backend_write_cb(pb, state) : 0;
 }
-static PRBool
-backend_be_write_ignore(Slapi_PBlock *pb)
-{
-    char *dn = NULL;
-    Slapi_DN *target_sdn = NULL;
-    int check;
-    int i = 0;
-    PRBool ignore = PR_FALSE;
-
-    /* Check if the target DN is a subordinates of
-     * on of the ignored containers
-     */
-    slapi_pblock_get(pb, SLAPI_ORIGINAL_TARGET, &dn);
-    target_sdn = slapi_sdn_new_dn_byval(dn);
-
-    for (i = 0; ignored_containers_sdn[i]; i++) {
-        check  = slapi_sdn_issuffix(target_sdn, ignored_containers_sdn[i]);
-        if (check != 0) {
-            /* This entry is an ignored container */
-            ignore = PR_TRUE;
-            break;
-        }
-    }
-    slapi_sdn_free(&target_sdn);
-    return ignore;
-}
-
 
 static int
 backend_be_pre_write_cb(Slapi_PBlock *pb) {
@@ -2392,7 +2384,7 @@ backend_be_pre_write_cb(Slapi_PBlock *pb) {
     if (rw_monitor_enabled() == MAP_MONITOR_DISABLED) {
         return 0;
     }
-    if (backend_be_write_ignore(pb)) {
+    if (backend_shr_write_ignore(pb)) {
 #if DEBUG_MAP_LOCK
         slapi_log_error(SLAPI_LOG_FATAL, "schemacompat",
                 "backend_be_pre_write_cb: (%p) operation is not impacting schema compat\n", PR_MyThreadId(), 1);
@@ -2484,7 +2476,7 @@ backend_be_post_write_cb(Slapi_PBlock *pb)
     if (rw_monitor_enabled() == MAP_MONITOR_DISABLED) {
         return 0;
     }
-    if (backend_be_write_ignore(pb)) {
+    if (backend_shr_write_ignore(pb)) {
 #if DEBUG_MAP_LOCK
         slapi_log_error(SLAPI_LOG_FATAL, "schemacompat",
                 "backend_be_post_write_cb: (%p) operation was not impacting schema compat\n", PR_MyThreadId(), 1);
