@@ -62,6 +62,8 @@
 #define PLUGIN_ID "schema-compat-plugin"
 #define PLUGIN_PREOP_ID PLUGIN_ID "-preop"
 #define PLUGIN_BETXN_PREOP_ID PLUGIN_ID "-betxn_preop"
+#define PLUGIN_BE_POSTOP_ID PLUGIN_ID "-be_postop"
+#define PLUGIN_BE_PREOP_ID PLUGIN_ID "-be_preop"
 #define PLUGIN_BETXN_POSTOP_ID PLUGIN_ID "-betxn_postop"
 #define PLUGIN_POSTOP_ID PLUGIN_ID "-postop"
 #define PLUGIN_INTERNAL_POSTOP_ID PLUGIN_ID "-internal-postop"
@@ -195,6 +197,13 @@ plugin_shutdown(Slapi_PBlock *pb)
 	if (state->plugin_base != NULL) {
 		slapi_ch_free((void **)&state->plugin_base);
 	}
+	if (ignored_containers_sdn) {
+		int i;
+		for (i = 0; ignored_containers_sdn[i]; i++) {
+			slapi_sdn_free(&ignored_containers_sdn[i]);
+		}
+		slapi_ch_free((void **)&ignored_containers_sdn);
+	}
 	slapi_log_error(SLAPI_LOG_PLUGIN, state->plugin_desc->spd_id,
 			"plugin shutdown completed\n");
 	return 0;
@@ -258,6 +267,35 @@ schema_compat_plugin_init_betxn_postop(Slapi_PBlock *pb)
 	}
 	return 0;
 }
+static int
+schema_compat_plugin_init_bepreop(Slapi_PBlock *pb)
+{
+	slapi_pblock_set(pb, SLAPI_PLUGIN_VERSION, SLAPI_PLUGIN_VERSION_03);
+	slapi_pblock_set(pb, SLAPI_PLUGIN_DESCRIPTION, &plugin_description);
+	slapi_pblock_set(pb, SLAPI_PLUGIN_PRIVATE, global_plugin_state);
+	if (backend_init_be_preop(pb, global_plugin_state) == -1) {
+		slapi_log_error(SLAPI_LOG_PLUGIN,
+				global_plugin_state->plugin_desc->spd_id,
+				"error registering be preoperation hooks\n");
+		return -1;
+	}
+	return 0;
+}
+static int
+schema_compat_plugin_init_bepostop(Slapi_PBlock *pb)
+{
+	slapi_pblock_set(pb, SLAPI_PLUGIN_VERSION, SLAPI_PLUGIN_VERSION_03);
+	slapi_pblock_set(pb, SLAPI_PLUGIN_DESCRIPTION, &plugin_description);
+	slapi_pblock_set(pb, SLAPI_PLUGIN_PRIVATE, global_plugin_state);
+	if (backend_init_be_postop(pb, global_plugin_state) == -1) {
+		slapi_log_error(SLAPI_LOG_PLUGIN,
+				global_plugin_state->plugin_desc->spd_id,
+				"error registering be postoperation "
+				"hooks\n");
+		return -1;
+	}
+	return 0;
+}
 #endif
 static int
 schema_compat_plugin_init_postop(Slapi_PBlock *pb)
@@ -300,6 +338,9 @@ schema_compat_plugin_init(Slapi_PBlock *pb)
 				"error setting up plugin\n");
 		return -1;
 	}
+
+    init_map_lock();
+
 	/* Read global configuration. */
 	if ((slapi_pblock_get(pb, SLAPI_PLUGIN_CONFIG_ENTRY,
 			      &plugin_entry) == 0) &&
@@ -341,6 +382,15 @@ schema_compat_plugin_init(Slapi_PBlock *pb)
 				"error registering betxn preoperation plugin\n");
 		return -1;
 	}
+        if (slapi_register_plugin("bepreoperation", TRUE,
+				  "schema_compat_plugin_init_bepreop",
+				  schema_compat_plugin_init_bepreop,
+				  PLUGIN_BE_PREOP_ID, NULL,
+				  state->plugin_identity) != 0) {
+		slapi_log_error(SLAPI_LOG_PLUGIN, state->plugin_desc->spd_id,
+				"error registering betxn preoperation plugin\n");
+		return -1;
+	}
 #endif
 	if (slapi_register_plugin("postoperation", TRUE,
 				  "schema_compat_plugin_init_postop",
@@ -370,6 +420,15 @@ schema_compat_plugin_init(Slapi_PBlock *pb)
 				"error registering betxn postoperation plugin\n");
 		return -1;
 	}
+        if (slapi_register_plugin("bepostoperation", TRUE,
+				  "schema_compat_plugin_init_bepostop",
+				  schema_compat_plugin_init_bepostop,
+				  PLUGIN_BE_POSTOP_ID, NULL,
+				  state->plugin_identity) != 0) {
+		slapi_log_error(SLAPI_LOG_PLUGIN, state->plugin_desc->spd_id,
+				"error registering betxn postoperation plugin\n");
+		return -1;
+	}
 #endif
 	if (slapi_register_plugin("preextendedop", TRUE,
 				  "schema_compat_plugin_init_extop",
