@@ -34,6 +34,9 @@ struct plugin_state {
 	Slapi_PluginDesc *plugin_desc;
 	unsigned int use_be_txns: 1;
 	PRInt32 ready_to_serve;
+        struct wrapped_mutex *priming_mutex;
+        unsigned int start_priming_thread: 1;   /* flag to allow spawning of the priming thread */
+        struct wrapped_thread *priming_tid; /* priming thread pid. use to join */
 
 	/* NIS-specific data. */
 	struct wrapped_thread *tid;
