@@ -77,7 +77,8 @@ slapi_log_error(int i, char *f, char *fmt, ...)
 int
 main(int argc, char **argv)
 {
-	int s, ret, port;
+	int s, port;
+	int ret __attribute__ ((unused));
 	s = socket(PF_INET, SOCK_DGRAM, 0);
 	if (s == -1) {
 		printf("error allocating socket\n");
@@ -94,8 +95,16 @@ main(int argc, char **argv)
 		printf("error creating portmap/rpcbind client socket\n");
 		return 1;
 	}
-	setregid(2516, 2516);
-	setreuid(2510, 2510);
+	if (setregid(2516, 2516) == -1) {
+		printf("error setting real and effective group id %s\n",
+		       strerror(errno));
+		return 1;
+	}
+	if (setreuid(2510, 2510) == -1) {
+		printf("error setting real and effective user id %s\n",
+		       strerror(errno));
+		return 1;
+	}
 	sleep(60);
 	portmap_unregister("portmap", &s, port, YPPROG, YPVERS,
 			   AF_INET, IPPROTO_TCP, 0);
